@@ -38,8 +38,10 @@ let quote_char c =
   match c with 
       '\\' | '^' | '$' | '.' | '[' | ']' | '|' 
     | '(' | ')' | '?' | '*' | '+' | '{' | '}' -> 
-	let s = String.create 2 in
-	s.[0] <- '\\'; s.[1] <- c; s
+	let s = Bytes.create 2 in
+	Bytes.set s 0 '\\';
+	Bytes.set s 1 c;
+	Bytes.unsafe_to_string s
     | '\000' -> "\\000"
     | c -> string c
 
@@ -279,7 +281,6 @@ let process_regexp _loc ~sharing re re_name =
   let postbindings =
     if sharing then
       [ shared_id, <:expr< Pcre.make_ovector $get_re_noargs$ >>;
-	subgroups2 re_name, <:expr< fst $lid:shared_id$ >>;
 	shared_ovector re_name, <:expr< snd $lid:shared_id$ >> ]
     else [] in
   (re_args, re_source, named_groups, postbindings)
@@ -385,8 +386,8 @@ let convert _loc conv e =
       None -> e
     | Some f ->
 	match f with
-	    `Int -> <:expr< Pervasives.int_of_string $e$ >>
-	  | `Float -> <:expr< Pervasives.float_of_string $e$ >>
+	    `Int -> <:expr< Stdlib.int_of_string $e$ >>
+	  | `Float -> <:expr< Stdlib.float_of_string $e$ >>
 	  | `Option -> <:expr< let s = $e$ in 
 	                       if s = "" then None 
 			       else Some s >>
@@ -478,7 +479,6 @@ let macro_match ?(ignore_bindings = false)
   let target = <:expr< $lid:target_name$ >> in
   let substrings = substrings_of_target target in
   let sv = shared_ovector re_name in
-  let sg2 = subgroups2 re_name in
   let result =
     if ignore_bindings then expr
     else insert_bindings _loc substrings named_groups expr in
@@ -493,7 +493,7 @@ let macro_match ?(ignore_bindings = false)
 	    do { Pcre.unsafe_pcre_exec 
 		   (Obj.magic 0 : Pcre.irflag) 
 		   $get_re$ (match pos with [ None -> 0 | Some n -> n]) 
-		   $target$ $lid:sg2$
+		   0 $target$
 		   $lid:sv$ None;
 		 $lid:sv$ }) : Pcre.substrings) in
     $result$ >>
